<div align="center">
<img src="https://raw.githubusercontent.com/Zipstack/unstract-adapters/main/docs/assets/unstract_u_logo.png" style="height: 120px">

# Unstract

## No-code LLM Platform to launch APIs and ETL Pipelines to structure unstructured documents

</div>

# Unstract Adapters

This is Unstract's python package which helps to configure to a number of different LLMs, Embeddings and VectorDBs.
For further details on the list of supported LLMs, Embeddings and Vector DBs,, please visit https://github.com/Zipstack/unstract

## Installation

### Local Development

To get started with local development, 
- Create and source a virtual environment if you haven't already following [these steps](/README.md#create-your-virtual-env).
- If you're using Mac, install the below library needed for PyMSSQL
```
brew install pkg-config freetds
```
- Install the required dependencies with
```shell
pdm install
```
